@@ -39,14 +39,13 @@
 #define WIFSIGNALED(stat_val)   ((int)((stat_val) & 0xFF) != 0)
 #endif
 
-
 extern char *stdout_log_name;
 extern char *stderr_log_name;
-
+extern char *stdout_log_template;
+extern char *stderr_log_template;
 
 extern int start PROTO ((char *, int));
 extern void remove_log PROTO (());
 extern void display_errors PROTO ((char *));
 
-
 #endif  /* _GIT_SYSTEM_H */
